@@ -10,7 +10,13 @@
 #' @export
 as.vpts <- function(data) {
   assertthat::assert_that(inherits(data,"data.frame"))
-  
+
+  # if dbz_all is a column name, rename to bioRad naming DBZH
+  if("dbz_all" %in% names(data)){
+    data <- data %>%
+      dplyr::rename(DBZH = "dbz_all")
+  }
+
   validate_vpts(data)
 
   height <- datetime <- source_file <- radar <- NULL
@@ -59,40 +65,46 @@ as.vpts <- function(data) {
     regular <- FALSE
   }
 
-# Get attributes
-radar_height <- data[["radar_height"]][1]
-interval <- unique(heights[-1] - heights[-length(heights)])
-wavelength <- data[["radar_wavelength"]][1]
+  # Get attributes
+  radar_height <- data[["radar_height"]][1]
+  interval <- unique(heights[-1] - heights[-length(heights)])
+  wavelength <- data[["radar_wavelength"]][1]
 
-# Check and warn for multiple values of specific attributes and return only the first values of those attributes
-check_multivalue_attributes <- function(data) {
-  attributes <- c("radar_longitude", "radar_latitude", "rcs", "sd_vvp_threshold")
-  first_values <- list()
-  for (attr in attributes) {
-    if (length(unique(data[[attr]])) > 1) {
-      warning(paste0("multiple ", as.character(substitute(attr))," values found, storing only first (",
-                     as.character(data[[attr]][1]), ") as the functional attribute."))
+  # Check and warn for multiple values of specific attributes and return only the first values of those attributes
+  check_multivalue_attributes <- function(data) {
+    attributes <- c("radar_longitude", "radar_latitude", "rcs", "sd_vvp_threshold")
+    first_values <- list()
+    for (attr in attributes) {
+      if (length(unique(data[[attr]])) > 1) {
+        warning(paste0("multiple ", as.character(substitute(attr))," values found, storing only first (",
+                       as.character(data[[attr]][1]), ") as the functional attribute."))
+      }
+      first_values[[attr]] <- data[[attr]][1]
     }
-    first_values[[attr]] <- data[[attr]][1]
+      return(first_values)
   }
-    return(first_values)
-}
 
   first_values <- check_multivalue_attributes(data)
-  
+
   # Directly extract and assign values from the list
   lon <- first_values$radar_longitude
   lat <- first_values$radar_latitude
   rcs <- first_values$rcs
   sd_vvp_threshold <- first_values$sd_vvp_threshold
-  
-  # Define set of radar variables that must be present at each height (including alternatives)
-  radvars <- c("u", "v", "w", "ff", "dd", "sd_vvp", "gap", "eta", "dens", "dbz", "dbz_all", "n", "n_dbz", "n_all", "n_dbz_all")
-  radvars <- c(radvars, unlist(vpts_schema$fields$nameAlternatives[vpts_schema$fields$name %in% radvars]))
 
-  data <- df_to_mat_list(data, radvars)
+  # column names not to store in the vpts$data slot
+  radvars_exclude <- c("radar","datetime","height","rcs","sd_vvp_threshold","radar_latitude","radar_longitude","radar_height","radar_wavelength")
+  # radvars to include in vpts$data slot
+  radvars <- names(data)[!names(data) %in% radvars_exclude]
 
-    # List of vectors to check
+  # calculate number of vertical profiles present
+  n_vp <- nrow(data)/length(heights)
+
+  # cast data.frame to list of matrices
+  data_output <- lapply(radvars, function(x) matrix(data[[x]],ncol=n_vp))
+  names(data_output)=radvars
+
+  # List of vectors to check
   vectors_to_check <- list(heights = heights, interval = interval, radar_height = radar_height, lon = lon, lat = lat)
 
   # Identify empty vectors
@@ -110,7 +122,7 @@ check_multivalue_attributes <- function(data) {
     height = heights,
     daterange = c(min(datetime), max(datetime)),
     timesteps = difftimes,
-    data = data,
+    data = data_output,
     attributes = list(
       where = data.frame(
         interval = as.integer(interval),
