@@ -23,9 +23,9 @@
 #' # Get summary info for this parameter
 #' param
 get_param <- function(x, param) {
-  assert_that(class(x) == "scan", msg = "`x` must be a scan object.")
+  assertthat::assert_that(class(x) == "scan", msg = "`x` must be a scan object.")
   if (!(param %in% names(x$params))) stop(
-    glue("Can't find parameter `{param}` in `x`.")
+    glue::glue("Can't find parameter `{param}` in `x`.")
   )
   x$params[[param]]
 }
