@@ -38,7 +38,7 @@ rcs.vp <- function(x) {
 #'
 #' @export
 rcs.list <- function(x) {
-  vptest <- sapply(x, function(y) is(y, "vp"))
+  vptest <- sapply(x, function(y) methods::is(y, "vp"))
   if (FALSE %in% vptest) {
     stop("`x` must be list of `vp` objects.")
   }
@@ -71,6 +71,8 @@ rcs.vpi <- function(x) {
 #' @inheritParams rcs
 #' @param value Numeric. The radar cross section value to assign in cm^2.
 #'
+#' @return The input object with updated density `x$data$dens` and updated radar cross section attribute.
+#'
 #' @export
 #'
 #' @seealso
@@ -98,8 +100,8 @@ rcs.vpi <- function(x) {
 #' @export
 `rcs<-.vp` <- function(x, value) {
   stopifnot(inherits(x, "vp"))
-  assert_that(is.numeric(value))
-  assert_that(value > 0)
+  assertthat::assert_that(is.numeric(value))
+  assertthat::assert_that(value > 0)
   x$attributes$how$rcs_bird <- value
   x$data$dens <- x$data$eta / value
   if (is.numeric(x$attributes$how$sd_vvp_thresh)) {
@@ -116,7 +118,7 @@ rcs.vpi <- function(x) {
 #'
 #' @export
 `rcs<-.list` <- function(x, value) {
-  vptest <- sapply(x, function(y) is(y, "vp"))
+  vptest <- sapply(x, function(y) methods::is(y, "vp"))
   if (FALSE %in% vptest) {
     stop("`x` must be list of `vp` objects.")
   }
@@ -130,8 +132,8 @@ rcs.vpi <- function(x) {
 #' @export
 `rcs<-.vpts` <- function(x, value) {
   stopifnot(inherits(x, "vpts"))
-  assert_that(is.numeric(value))
-  assert_that(value > 0)
+  assertthat::assert_that(is.numeric(value))
+  assertthat::assert_that(value > 0)
   x$attributes$how$rcs_bird <- value
   x$data$dens <- x$data$eta / value
   if (is.numeric(x$attributes$how$sd_vvp_thresh)) {
